from django.conf.urls.defaults import patterns

# URL patterns for django-csvimport

urlpatterns = patterns('django-csvimport.views',
  # Add url patterns here
)
